@@ -5,7 +5,7 @@ xlab="", ylab="", axes=FALSE, lablong="", lablat="")
 {
 # Verification of the Spatial Object sp.obj
 class.obj<-class(sp.obj)[1]
-
+spdf<-(class.obj=="SpatialPolygonsDataFrame")
 if(substr(class.obj,1,7)!="Spatial") stop("sp.obj may be a Spatial object")
 if(substr(class.obj,nchar(class.obj)-8,nchar(class.obj))!="DataFrame") stop("sp.obj should contain a data.frame")
 if(!is.numeric(name.var) & is.na(match(as.character(name.var),names(sp.obj)))) stop("name.var is not included in the data.frame of sp.obj")
@@ -25,7 +25,7 @@ listvar<-sp.obj@data
 listnomvar<-names.attr
 
 # Code which was necessary in the previous version
- if(is.null(carte) & class.obj=="SpatialPolygonsDataFrame") carte<-spdf2list(sp.obj)$poly
+# if(is.null(carte) & class.obj=="SpatialPolygonsDataFrame") carte<-spdf2list(sp.obj)$poly
 
  # for identifyng the selected sites
 ifelse(identify, label<-row.names(listvar),label<-"")
@@ -39,23 +39,7 @@ ifelse(identify, label<-row.names(listvar),label<-"")
   # Is W normalized ?
   is.norm<-all(apply(W,1,sum)==rep(1,n))
   
-# Is there a Tk window already open ?
-if(interactive())
-{
- if(!exists("GeoXp.open",envir = baseenv())||length(ls(envir=.TkRoot$env, all.names=TRUE))==2) # new environment
- {
-  assign("GeoXp.open", TRUE, envir = baseenv())
- }
- else
- {if(get("GeoXp.open",envir= baseenv()))
-   {stop("Warning : a GeoXp function is already open. Please, close Tk window before calling a new GeoXp function to avoid conflict between graphics")}
-  else
-  {assign("GeoXp.open", TRUE, envir = baseenv())}
- }
-}
-
-
-#initialisation
+  #initialisation
 if(xlab=="") xlab=name.var
 if(ylab=="") ylab=paste("spatially lagged",name.var)
   obs<-vector(mode = "logical", length = length(long))
@@ -124,7 +108,11 @@ obsq[which((var <= mean(var)) & (wvar > mean(wvar)))] <- 2
 obsq[which((var < mean(var)) & (wvar <= mean(wvar)))] <- 3
 obsq[which((var >= mean(var)) & (wvar < mean(wvar)))] <- 4
  
-  
+ # i de moran local
+  x.centre<-(var-mean(var))
+  wx.centre<-(W%*%x.centre)
+  ilocal <- (x.centre/var(x.centre)) * (wx.centre)  
+
 ####################################################
 # slection d'un point
 ####################################################
@@ -138,6 +126,8 @@ pointfunc<-function()
       { dev.set(2)
         title("ACTIVE DEVICE", cex.main = 0.8, font.main = 3, col.main='red')
         title(sub = "To stop selection, click on the right button of the mouse and stop (for MAC, ESC)", cex.sub = 0.8, font.sub = 3,col.sub='red')
+        if(spdf & nrow(sp.obj)>75 & !buble) 
+           {points(long,lat,pch=16,col='royalblue')}
       }
      else
      { dev.set(3)
@@ -154,13 +144,24 @@ pointfunc<-function()
             if(is.null(loc)) 
             {
               quit<-TRUE
-              carte(long=long, lat=lat, obs=obs,  carte=carte,nocart=nocart, classe=obsq,
+              carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj, carte=carte,nocart=nocart, classe=obsq,
               couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
               nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
               label=label, cex.lab=cex.lab, labmod=names.arg)   
               next
             }           
-            obs<<-selectmap(var1=long,var2=lat,obs=obs,Xpoly=loc[1], Ypoly=loc[2], method="point") 
+           if(!spdf|nrow(sp.obj)>75)
+            { 
+            obs<<-selectmap(var1=long,var2=lat,obs=obs,Xpoly=loc[1], Ypoly=loc[2], method="point")}
+           else
+           {if(gContains(sp.obj,SpatialPoints(cbind(loc$x,loc$y),proj4string=CRS(proj4string(sp.obj)))))
+            {for (i in 1:nrow(sp.obj))
+             {if(gContains(sp.obj[i,],SpatialPoints(cbind(loc$x,loc$y),proj4string=CRS(proj4string(sp.obj)))))
+              {obs[i]<<-!obs[i]
+             break}  
+             }
+            } 
+           }
         }
         else
         {
@@ -169,7 +170,7 @@ pointfunc<-function()
             if(is.null(loc)) 
             {
               quit<-TRUE
-              graphique(var1=var, var2=wvar, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
+              graphique(var1=var, var2=wvar, var3=ilocal, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
               symbol=pch2, locmoran=locmoran,obsq=obsq, cex.lab=cex.lab,buble=buble2, cbuble=z2, 
               legmap=legmap2, legends=legends2, bin=is.norm)
               next
@@ -178,12 +179,12 @@ pointfunc<-function()
         }
         
         #graphiques
-        carte(long=long, lat=lat, obs=obs,  carte=carte,nocart=nocart, classe=obsq,
+        carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj,  carte=carte,nocart=nocart, classe=obsq,
         couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
         nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
         label=label, cex.lab=cex.lab, labmod=names.arg)      
 
-        graphique(var1=var, var2=wvar, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
+        graphique(var1=var, var2=wvar, var3=ilocal, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
         symbol=pch2, locmoran=locmoran,obsq=obsq, cex.lab=cex.lab,buble=buble2, cbuble=z2, 
         legmap=legmap2, legends=legends2, bin=is.norm)
       
@@ -191,6 +192,8 @@ pointfunc<-function()
       { dev.set(2)
         title("ACTIVE DEVICE", cex.main = 0.8, font.main = 3, col.main='red')
         title(sub = "To stop selection, click on the right button of the mouse and stop (for MAC, ESC)", cex.sub = 0.8, font.sub = 3,col.sub='red')
+        if(spdf & nrow(sp.obj)>75 & !buble) 
+           {points(long,lat,pch=16,col='royalblue')}
       }
      else
      { dev.set(3)
@@ -258,6 +261,8 @@ polyfunc<-function()
         if(maptest)
         {
           dev.set(2)
+          if(spdf) 
+          {points(long,lat,pch=16,col='royalblue')}
           loc<-locator(1)
           if(is.null(loc)) 
             {
@@ -296,12 +301,12 @@ polyfunc<-function()
     }
 
     #graphiques
-        carte(long=long, lat=lat, obs=obs,  carte=carte,nocart=nocart, classe=obsq,
+        carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj,  carte=carte,nocart=nocart, classe=obsq,
         couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
         nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
         label=label, cex.lab=cex.lab, labmod=names.arg)        
 
-        graphique(var1=var, var2=wvar, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
+        graphique(var1=var, var2=wvar,  var3=ilocal, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
         symbol=pch2, locmoran=locmoran,obsq=obsq, cex.lab=cex.lab,buble=buble2, cbuble=z2, 
         legmap=legmap2, legends=legends2, bin=is.norm)
         
@@ -365,14 +370,16 @@ quadfunc <- function()
 
     obs[which(obsq == num)] <<- !obs[which(obsq == num)]
 
-    carte(long=long, lat=lat, obs=obs, classe=obsq,  carte=carte,nocart=nocart, labmod=names.arg,
-    couleurs=col3,symbol=pch2, method="Quadrant",buble=buble,cbuble=z,criteria=criteria,nointer=nointer,legmap=legmap,
+    carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj,  classe=obsq,  carte=carte,nocart=nocart, labmod=names.arg, W=W,
+    couleurs=col3,symbol=pch2, method=method,buble=buble,cbuble=z,criteria=criteria,nointer=nointer,legmap=legmap,
     legends=legends,axis=axes,lablong=lablong, lablat=lablat, label=label, cex.lab=cex.lab) 
 
-    graphique(var1=var, var2=wvar, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
+    graphique(var1=var, var2=wvar,  var3=ilocal, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
     symbol=pch2, locmoran=locmoran,obsq=obsq, cex.lab=cex.lab,buble=buble2, cbuble=z2, 
     legmap=legmap2, legends=legends2, bin=is.norm)
     
+        
+            
     if ((graphChoice != "") && (varChoice1 != "") && (length(dev.list()) > 2))
      {
       graphique(var1=listvar[,which(listnomvar == varChoice1)], var2=listvar[,which(listnomvar == varChoice2)],
@@ -387,32 +394,32 @@ quadfunc <- function()
 quad1func <- function()
 {
   num <<- 1 
-  method <<- "Quadrant" 
-  graph <<- "Quadrant"  
+  method <<- ifelse(flower,"Neighbourplot1","Quadrant") 
+#  graph <<- "Quadrant"  
   quadfunc()
 }
 
 quad2func <- function()
 {
  num <<- 2  
- method <<- "Quadrant"
- graph <<- "Quadrant"      
+  method <<- ifelse(flower,"Neighbourplot1","Quadrant") 
+ #graph <<- "Quadrant"      
  quadfunc()
 }
 
 quad3func <- function()
 {
  num <<- 3
- method <<- "Quadrant"
- graph <<- "Quadrant"    
+  method <<- ifelse(flower,"Neighbourplot1","Quadrant") 
+# graph <<- "Quadrant"    
  quadfunc()
 }
 
 quad4func <- function()
 {
  num <<- 4
- method <<- "Quadrant"
- graph <<- "Quadrant"    
+  method <<- ifelse(flower,"Neighbourplot1","Quadrant") 
+# graph <<- "Quadrant"    
  quadfunc()
 }
 
@@ -425,7 +432,7 @@ quad4func <- function()
     if(!choix.col)
     {choix.col<<-TRUE
      method <<- "Quadrant"
-     res1<-choix.couleur("Moran",col=col[1],pch=pch[1],legends=legends)     
+     res1<-choix.couleur("Moran",col=col[1],pch=pch[1],legends=legends,spdf=spdf)     
      if(length(res1$col2)==4)
       {col2 <<- res1$col2
        col3 <<- col2 }
@@ -444,12 +451,12 @@ quad4func <- function()
      legends <<- list(legends[[1]],FALSE,legends[[3]],"")
     }
 
-carte(long=long, lat=lat, obs=obs, carte=carte,nocart=nocart, classe=obsq,
+carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj,  carte=carte,nocart=nocart, classe=obsq,
 couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
 nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
 label=label, cex.lab=cex.lab,labmod=names.arg)     
 
-graphique(var1=var, var2=wvar, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
+graphique(var1=var, var2=wvar,  var3=ilocal, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
 symbol=pch2, locmoran=locmoran,obsq=obsq, cex.lab=cex.lab,buble=buble2, cbuble=z2, 
 legmap=legmap2, legends=legends2, bin=is.norm)
         
@@ -492,7 +499,7 @@ cartfunc <- function()
   if (length(carte) != 0)
    {
     ifelse(!nocart,nocart<<-TRUE,nocart<<-FALSE)
-    carte(long=long, lat=lat, obs=obs, carte=carte,nocart=nocart, classe=obsq,
+    carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj,  carte=carte,nocart=nocart, classe=obsq,
     couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
     nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
     label=label, cex.lab=cex.lab,labmod=names.arg)        
@@ -513,12 +520,12 @@ SGfunc<-function()
 {
     obs<<-vector(mode = "logical", length = length(long));
 
-carte(long=long, lat=lat, obs=obs, carte=carte,nocart=nocart, classe=obsq,
+carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj,  carte=carte,nocart=nocart, classe=obsq,
 couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
 nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
 label=label, cex.lab=cex.lab,labmod=names.arg)     
 
-graphique(var1=var, var2=wvar, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
+graphique(var1=var, var2=wvar,  var3=ilocal, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
 symbol=pch2, locmoran=locmoran,obsq=obsq, cex.lab=cex.lab,buble=buble2, cbuble=z2, 
 legmap=legmap2, legends=legends2, bin=is.norm)
     
@@ -561,7 +568,7 @@ fnointer<-function()
  if (length(criteria) != 0)
  {
  ifelse(!nointer,nointer<<-TRUE,nointer<<-FALSE)
- carte(long=long, lat=lat, obs=obs, carte=carte,nocart=nocart, classe=obsq,
+ carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj, carte=carte,nocart=nocart, classe=obsq,
  couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
  nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
  label=label, cex.lab=cex.lab,labmod=names.arg)       
@@ -587,7 +594,7 @@ fbubble<-function()
   z <<- res2$z
   legmap <<- res2$legmap
   
-carte(long=long, lat=lat, obs=obs, carte=carte,nocart=nocart, classe=obsq,
+carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj, carte=carte,nocart=nocart, classe=obsq,
 couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
 nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
 label=label, cex.lab=cex.lab,labmod=names.arg)    
@@ -599,10 +606,7 @@ label=label, cex.lab=cex.lab,labmod=names.arg)
 ####################################################
 
 lisa<-function()
-{
-  x.centre<-(var-mean(var))
-  wx.centre<-(W%*%x.centre)
-  ilocal <- (x.centre/sd(x.centre)) * (wx.centre/sd(x.centre))          
+{        
   res3<-choix.bubble(buble2,abs(ilocal),"ilocal",legends2)
   
   buble2 <<- res3$buble
@@ -610,7 +614,7 @@ lisa<-function()
   z2 <<- res3$z
   legmap2 <<- res3$legmap
   
-graphique(var1=var, var2=wvar, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
+graphique(var1=var, var2=wvar,  var3=ilocal, obs=obs, num=3, graph=graph, labvar=labvar, couleurs=col2,
 symbol=pch2, locmoran=locmoran,obsq=obsq, cex.lab=cex.lab,buble=buble2, cbuble=z2, 
 legmap=legmap2, legends=legends2, bin=is.norm)
  
@@ -659,14 +663,38 @@ permutation<-function()
   tkfocus(tt1)
 }
 
-carte(long=long, lat=lat, obs=obs, carte=carte,nocart=nocart, classe=classe,
-couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
-nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
-label=label, cex.lab=cex.lab)     
+#################################################
+###########   Representation
 
-graphique(var1=var, var2=wvar, obs=obs, num=3, graph="Moran", labvar=labvar, couleurs=col2, symbol=pch2,
-locmoran=locmoran,obsq=obsq,buble=buble2, cbuble=z2, legmap=legmap2, legends=legends2, bin=is.norm)
-        
+# Is there a Tk window already open ?
+if(interactive())
+{
+ if(!exists("GeoXp.open",envir = baseenv())||length(ls(envir=.TkRoot$env, all.names=TRUE))==2) # new environment
+ {
+   carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj, carte=carte,nocart=nocart, classe=classe,
+   couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
+   nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
+   label=label, cex.lab=cex.lab)     
+
+   graphique(var1=var, var2=wvar,  var3=ilocal, obs=obs, num=3, graph="Moran", labvar=labvar, couleurs=col2, symbol=pch2,
+   locmoran=locmoran,obsq=obsq,buble=buble2, cbuble=z2, legmap=legmap2, legends=legends2, bin=is.norm)
+   assign("GeoXp.open", TRUE, envir = baseenv())
+ }
+ else
+ {if(get("GeoXp.open",envir= baseenv()))
+   {stop("Warning : a GeoXp function is already open. Please, close Tk window before calling a new GeoXp function to avoid conflict between graphics")}
+  else
+  {carte(long=long, lat=lat, obs=obs,  sp.obj=sp.obj, carte=carte,nocart=nocart, classe=classe,
+    couleurs=col3, symbol=pch2, W=W, method=method, buble=buble, cbuble=z, criteria=criteria,
+    nointer=nointer, legmap=legmap, legends=legends,axis=axes,lablong=lablong, lablat=lablat,
+    label=label, cex.lab=cex.lab)     
+
+   graphique(var1=var, var2=wvar,  var3=ilocal, obs=obs, num=3, graph="Moran", labvar=labvar, couleurs=col2, symbol=pch2,
+   locmoran=locmoran,obsq=obsq,buble=buble2, cbuble=z2, legmap=legmap2, legends=legends2, bin=is.norm)
+   assign("GeoXp.open", TRUE, envir = baseenv())}
+ }
+}
+     
 
 ####################################################
 # cration de la boite de dialogue
